@@ -3,11 +3,17 @@ library("R.utils")
 pathT <- tempdir()
 mprint(pathT)
 
-path <- file.path(pathT, "foo")
+path <- file.path(pathT, "foo", "bar")
 mprint(path)
 mkdirs(path)
 stopifnot(isDirectory(path))
 
+paths <- c(dirname(path), path)
+stopifnot(all(isDirectory(paths)))
+
+removeDirectory(dirname(path), recursive=TRUE)
+
+
 # Windows has a undocumented "feature" that for some set
 # ups on some machines (not all) it will for instance
 # silently drop a trailing period and create the directory
@@ -18,6 +24,7 @@ mprint(path)
 mkdirs(path)
 tryCatch({
   stopifnot(isDirectory(path))
+  removeDirectory(path)
 }, error = function(ex) {
   mprint(ex)
 })
